---
title: Privacy policy
prefix: Privacy
...

This website logs information about who visited which page, and when.

This information is logged in a rotated log file that is deleted every month. The information is not stored historically.

This information is not used for any purpose other than to debug our application. Specifically:

- We do not share this information with third parties
- We do not send you information
- We use cookies to preserve your logged-in status within the application. This is not used for other purposes

For any questions, please email `contact@gramener.com` or write to:

Gramener Technologies Pvt Ltd
<br>Plot 9/2, 2nd Floor
<br>Survey 64, HUDA Techno Enclave
<br>Phase 2, Madhapur
<br>Hyderabad 500081, India
